==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/AuthorityKeyIdentifier.h <==
// public class gnu.java.security.x509.ext.AuthorityKeyIdentifier

// class file dependencies
// @dep_class 1b781987c14d30bc gnu_java_security_x509_ext_AuthorityKeyIdentifier
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_AuthorityKeyIdentifier_H_
#define _JC_gnu_java_security_x509_ext_AuthorityKeyIdentifier_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_x509_ext_GeneralNames$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_refs	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_nonrefs	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$refs	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$refs;
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$nonrefs	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object;

typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$fields_struct	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vmethods	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtable	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24AuthorityKeyIdentifier;
};
extern _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$fields_struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_gnu_java_security_x509_ext_GeneralNames$object *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$getAuthorityCertIssuer$85d14e9a479f987e(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *);
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$getAuthorityCertSerialNumber$3930aa7cc162a0a5(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *);
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$getKeyIdentifier$142fba11413589b7(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method_info$getAuthorityCertIssuer$85d14e9a479f987e;
extern _jc_method _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method_info$getAuthorityCertSerialNumber$3930aa7cc162a0a5;
extern _jc_method _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method_info$getKeyIdentifier$142fba11413589b7;
extern _jc_method _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vmethods {
	struct _jc_gnu_java_security_x509_ext_GeneralNames$object	*(*getAuthorityCertIssuer$85d14e9a479f987e)(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *);
	struct _jc_java_math_BigInteger$object	*(*getAuthorityCertSerialNumber$3930aa7cc162a0a5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *);
	_jc_byte_array	*(*getKeyIdentifier$142fba11413589b7)(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vmethods	gnu_java_security_x509_ext_AuthorityKeyIdentifier;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_refs {
	_jc_byte_array	*keyIdentifier;
	struct _jc_gnu_java_security_x509_ext_GeneralNames$object	*authorityCertIssuer;
	struct _jc_java_math_BigInteger$object	*authorityCertSerialNumber;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$refs {
    _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_refs	gnu_java_security_x509_ext_AuthorityKeyIdentifier;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_nonrefs	gnu_java_security_x509_ext_AuthorityKeyIdentifier;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object {
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_AuthorityKeyIdentifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_AuthorityKeyIdentifier_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/AuthorityKeyIdentifier.h <==
// public class gnu.java.security.x509.ext.AuthorityKeyIdentifier

// class file dependencies
// @dep_class 1b781987c14d30bc gnu_java_security_x509_ext_AuthorityKeyIdentifier
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_AuthorityKeyIdentifier_H_
#define _JC_gnu_java_security_x509_ext_AuthorityKeyIdentifier_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_x509_ext_GeneralNames$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_refs	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_nonrefs	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$refs	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$refs;
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$nonrefs	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object;

typedef struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$fields_struct	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vmethods	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtable	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24AuthorityKeyIdentifier;
};
extern _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$fields_struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_security_x509_ext_GeneralNames$object *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$getAuthorityCertIssuer$85d14e9a479f987e(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$getAuthorityCertSerialNumber$3930aa7cc162a0a5(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$getKeyIdentifier$142fba11413589b7(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method_info$getAuthorityCertIssuer$85d14e9a479f987e;
extern _jc_method _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method_info$getAuthorityCertSerialNumber$3930aa7cc162a0a5;
extern _jc_method _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method_info$getKeyIdentifier$142fba11413589b7;
extern _jc_method _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vmethods {
	struct _jc_gnu_java_security_x509_ext_GeneralNames$object	*(*getAuthorityCertIssuer$85d14e9a479f987e)(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getAuthorityCertSerialNumber$3930aa7cc162a0a5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getKeyIdentifier$142fba11413589b7)(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vmethods	gnu_java_security_x509_ext_AuthorityKeyIdentifier;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_refs {
	_jc_byte_array	*keyIdentifier;
	struct _jc_gnu_java_security_x509_ext_GeneralNames$object	*authorityCertIssuer;
	struct _jc_java_math_BigInteger$object	*authorityCertSerialNumber;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$refs {
    _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_refs	gnu_java_security_x509_ext_AuthorityKeyIdentifier;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$sub_nonrefs	gnu_java_security_x509_ext_AuthorityKeyIdentifier;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$object {
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$vtype _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_AuthorityKeyIdentifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_AuthorityKeyIdentifier$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_AuthorityKeyIdentifier_H_ */
